@@ -1,12 +1,12 @@
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 from pprint import pformat
 
 from django.utils.html import escape
 
 FIXEDWIDTH_STYLE = '''\
-<span title="%s" style="font-size: %spt; \
-font-family: Menlo, Courier; ">%s</span> \
+<span title="{0}" style="font-size: {1}pt; \
+font-family: Menlo, Courier; ">{2}</span> \
 '''
 
 
@@ -43,7 +43,8 @@ def fixedwidth(field, name=None, pt=6, width=16, maxlen=64, pretty=False):
 
         if len(shortval) > maxlen:
             shortval = shortval[:maxlen] + '...'
-        styled = FIXEDWIDTH_STYLE % (escape(val[:255]), pt,
-                                     escape(shortval))
+        styled = FIXEDWIDTH_STYLE.format(
+            escape(val[:255]), pt, escape(shortval),
+        )
         return styled.replace('|br/|', '<br/>')
     return f
