@@ -1,5 +1,6 @@
 from __future__ import absolute_import, unicode_literals
 
+import django
 import os
 import sys
 
@@ -14,6 +15,8 @@ be used in that same thread.  The object with alias '{0}' \
 was created in thread id {1} and this is thread id {2}.\
 """
 
+VALIDATE_MODELS = not django.VERSION >= (1, 7)
+
 
 def patch_thread_ident():
     # monkey patch django.
@@ -55,8 +58,10 @@ patch_thread_ident()
 
 class CeleryCommand(BaseCommand):
     options = BaseCommand.option_list
-    skip_opts = ['--app', '--loader', '--config']
+    skip_opts = ['--app', '--loader', '--config', '--no-color']
+    requires_model_validation = VALIDATE_MODELS
     keep_base_opts = False
+    stdout, stderr = sys.stdout, sys.stderr
 
     def get_version(self):
         return 'celery {c.__version__}\ndjango-celery {d.__version__}'.format(
