@@ -3,14 +3,14 @@
 Start the celery clock service from the Django management command.
 
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
-from celery.bin import celerybeat
+from celery.bin import beat
 
 from djcelery.app import app
 from djcelery.management.base import CeleryCommand
 
-beat = celerybeat.BeatCommand(app=app)
+beat = beat.beat(app=app)
 
 
 class Command(CeleryCommand):
