@@ -3,7 +3,7 @@
 Start the celery clock service from the Django management command.
 
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 import sys
 
