@@ -1,6 +1,6 @@
 # -- XXX This module must not use translation as that causes
 # -- a recursive loader import!
-from __future__ import absolute_import
+from __future__ import absolute_import, unicode_literals
 
 from datetime import datetime
 
@@ -85,3 +85,11 @@ def maybe_make_aware(value):
     if value:
         return make_aware(value)
     return value
+
+
+def is_database_scheduler(scheduler):
+    if not scheduler:
+        return False
+    from kombu.utils import symbol_by_name
+    from .schedulers import DatabaseScheduler
+    return issubclass(symbol_by_name(scheduler), DatabaseScheduler)
